<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/TR/xhtml1/strict">
<xsl:output method="xml" indent="yes" encoding="ISO-8859-2"/>

<!-- params -->
<xsl:param name="UNDEF" select="UNDEF"/>

<!-- templates -->
<xsl:template match="/">
<HTML>
<!-- head -->
<HEAD>
	<H2>Project <xsl:value-of select="//name"/> - <xsl:value-of select="//description/short"/></H2>
	<xsl:element name="META">
		<xsl:attribute name="name">keywords</xsl:attribute>
		<xsl:attribute name="content"><xsl:value-of select="//description/keywords"/></xsl:attribute>
	</xsl:element>
	<xsl:element name="META">
		<xsl:attribute name="name">description</xsl:attribute>
		<xsl:attribute name="content"><xsl:value-of select="//description/short"/></xsl:attribute>
	</xsl:element>
</HEAD>
<!-- body -->
<BODY>
	<TABLE>
		<!-- project description -->
		<TR>
			<TD><B>Name:</B></TD>
			<TD><FONT color="#565BB7"><B><xsl:value-of select="//name"/></B></FONT></TD>
		</TR>
		<TR>
			<TD><B>Type:</B></TD>
			<TD><xsl:value-of select="//type"/></TD>
		</TR>

		<TR>
			<TD><B>Description:</B></TD>
			<TD><xsl:value-of select="//description/full"/></TD>
		</TR>
		<TR>
			<TD><B>Author:</B></TD>
			<TD><xsl:value-of select="//author/name"/>
			    <xsl:variable name="EMAIL_DESPAM"><xsl:value-of select="//author/email"/></xsl:variable>
			    &#160;
			    <FONT color="red">&lt;<xsl:value-of select="substring-before($EMAIL_DESPAM, '@')"/>(at)<xsl:value-of select="substring-after($EMAIL_DESPAM, '@')"/>&gt;</FONT>
                         </TD>
		</TR>
		<TR>
			<TD><B>Status:</B></TD>
			<TD><FONT color="green"><xsl:value-of select="//status"/></FONT></TD>
		</TR>
		<xsl:if test="//version[@branch='stable'] != ''">
		<TR>
			<TD><B>Stable:</B></TD>
			<TD><FONT color="#66CDAA"><xsl:value-of select="//version[@branch='stable'][last()]/name"/>&#160;
						<xsl:apply-templates select="//version[@branch='stable'][last()]/url"/></FONT></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//version[last()][@branch='unstable'] != ''">
		<TR>
			<TD><B>UnStable:</B></TD>
			<TD><FONT color="#66CDAA"><xsl:value-of select="//version[last()][@branch='unstable']/name"/>&#160;
						<xsl:apply-templates select="//version[last()][@branch='unstable']/url"/></FONT></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//dependency != ''">
		<TR>
			<TD><B>Requires:</B></TD>
			<TD><xsl:apply-templates select="//dependency"/></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//dependent != ''">
		<TR>
			<TD><B>Depends:</B></TD>
			<TD><xsl:apply-templates select="//dependent"/></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//subproject != ''">
		<TR>
			<TD><B>Subprojects:</B></TD>
			<TD><xsl:apply-templates select="//subproject"/></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//freshmeat != ''">
		<TR>
			<TD><B><FONT color="red">Freshmeat:</FONT></B></TD>
			<TD><xsl:apply-templates select="//freshmeat"/></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//see != ''">
		<TR>
			<TD><B>See:</B></TD>
			<TD><xsl:apply-templates select="//see"/></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//doc != ''">
		<TR>
			<TD><B>Manuals:</B></TD>
			<TD><xsl:apply-templates select="//doc"/></TD>
		</TR>
		</xsl:if>
	</TABLE>
</BODY>
</HTML>
</xsl:template>

<!-- dependencies...etc -->
<xsl:template match="dependency|dependent|subproject|see|freshmeat|doc">
	<xsl:value-of select="name"/>&#160;<xsl:apply-templates select="url"/>&#160;&#160;
</xsl:template>

<xsl:template match="url">
	<xsl:if test=". != ''">
	<xsl:element name="A">
		<xsl:attribute name="href">
			<xsl:value-of select="."/>
		</xsl:attribute>[link]</xsl:element>
	</xsl:if>
</xsl:template>

</xsl:stylesheet>
<!-- EOF -->
