<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/TR/xhtml1/strict">
<xsl:output method="xml" indent="yes" encoding="ISO-8859-2"/>

<!-- params -->
<xsl:param name="UNDEF" select="UNDEF"/>

<!-- templates -->
<xsl:template match="/">
<HTML>
<!-- head -->
<HEAD>
	<TITLE>Project <xsl:value-of select="//name"/> - <xsl:value-of select="//description/short"/></TITLE>
	<xsl:element name="META">
		<xsl:attribute name="name">keywords</xsl:attribute>
		<xsl:attribute name="content"><xsl:value-of select="//description/keywords"/></xsl:attribute>
	</xsl:element>
	<xsl:element name="META">
		<xsl:attribute name="name">description</xsl:attribute>
		<xsl:attribute name="content"><xsl:value-of select="//description/short"/></xsl:attribute>
	</xsl:element>
</HEAD>
<!-- body -->
<BODY>
	<!-- up -->
	<A href=".." title="Directory Up"><FONT size="2"><B>UP</B></FONT></A>
	
	<!-- title -->
	<CENTER>
		<FONT size="+4" color="#565BB7"><B><xsl:value-of select="//name"/></B></FONT>
		<div/>
		<FONT size="-1"><B><xsl:value-of select="//description/short"/></B></FONT>
	</CENTER>

	<TABLE>
		<!-- project description -->
		<TR>
			<TD><B>Type:</B></TD>
			<TD><xsl:value-of select="//type"/></TD>
		</TR>

		<TR>
			<TD><B>Description:</B></TD>
			<TD><xsl:value-of select="//description/full"/></TD>
		</TR>
		<TR>
			<TD><B>Author:</B></TD>
			<TD><xsl:value-of select="//author/name"/>
			    <xsl:variable name="EMAIL_DESPAM"><xsl:value-of select="//author/email"/></xsl:variable>
			    &#160;
			    <FONT color="red">&lt;<xsl:value-of select="substring-before($EMAIL_DESPAM, '@')"/>(at)<xsl:value-of select="substring-after($EMAIL_DESPAM, '@')"/>&gt;</FONT>
                         </TD>
		</TR>
		<TR>
			<TD><B>Status:</B></TD>
			<TD><FONT color="green"><B><xsl:value-of select="//status"/></B></FONT></TD>
		</TR>
		<xsl:if test="//version[@branch='stable'] != ''">
		<TR>
			<TD><B>Stable:</B></TD>
  			<TD><FONT color="#66CDAA"><xsl:value-of select="//version[@branch='stable'][last()]/name"/>&#160;
						<xsl:apply-templates select="//version[@branch='stable'][last()]/url"/></FONT></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//version[last()][@branch='unstable'] != ''">
		<TR>
			<TD><B>UnStable:</B></TD>
			<TD><FONT color="#66CDAA"><xsl:value-of select="//version[last()][@branch='unstable']/name"/>&#160;
						<xsl:apply-templates select="//version[last()][@branch='unstable']/url"/></FONT></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//dependency != ''">
		<TR>
			<TD><B>Requires:</B></TD>
			<TD><xsl:apply-templates select="//dependency"/></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//dependent != ''">
		<TR>
			<TD><B>Depends:</B></TD>
			<TD><xsl:apply-templates select="//dependent"/></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//subproject != ''">
		<TR>
			<TD><B>Subprojects:</B></TD>
			<TD><xsl:apply-templates select="//subproject"/></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//freshmeat != ''">
		<TR>
			<TD><B><FONT color="red">Freshmeat:</FONT></B></TD>
			<TD><xsl:apply-templates select="//freshmeat"/></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//see != ''">
		<TR>
			<TD><B>See:</B></TD>
			<TD><xsl:apply-templates select="//see"/></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//changelog != ''">
		<TR>
			<TD><B>ChangeLog:</B></TD>
			<TD><xsl:apply-templates select="//changelog"/></TD>
		</TR>
		</xsl:if>
		<xsl:if test="//doc != ''">
		<TR>
			<TD><B>Manuals:</B></TD>
			<TD><xsl:apply-templates select="//doc"/></TD>
		</TR>
		</xsl:if>
	</TABLE>

	<!-- <HR width="60%"/> -->
	<BR/><BR/>

	<TABLE width="100%" border="1">
		<!-- project versions -->
		<TH colspan="20"><B><xsl:value-of select="//name"/> versions overview</B></TH>
		<TR>
			<TD width="100" align="center"><B>Branch</B></TD>
			<TD width="100" align="center"><B>Version</B></TD>
			<TD width="100" align="center"><B>Url</B></TD>
			<TD align="center"><B>Informations</B></TD>
		</TR>
		<xsl:apply-templates select="//version">
			<xsl:sort select="position()" data-type="number" order="descending"/>
		</xsl:apply-templates>
	</TABLE>
	<!-- banner -->
	<BR/><BR/>
	<CENTER>
		<HR width="30%"/>
		<FONT color="red" size="1">Page generated by <B><A href="http://devel.dob.sk/swpages/">SWPAGES 0.2.1</A></B> (simple web pages) using <B>XML</B> and <B>XSLT</B>.</FONT>
	</CENTER>
</BODY>
</HTML>
</xsl:template>

<!-- dependencies...etc -->
<xsl:template match="dependency|dependent|subproject|see|freshmeat|doc|about|changelog">
	<xsl:value-of select="name"/>&#160;<xsl:apply-templates select="url"/>&#160;&#160;
</xsl:template>

<xsl:template match="version">
	<TR>
		<TD align="center"><FONT color="magenta"><xsl:value-of select="@branch"/></FONT></TD>
		<TD align="center"><xsl:value-of select="name"/>
			<xsl:if test="phase != ''">
				(<xsl:value-of select="phase"/>)
			</xsl:if>
			<xsl:if test="codename != ''">
				&#160;[<FONT color="red"><xsl:value-of select="codename"/></FONT>]
			</xsl:if></TD>
		<TD align="center"><xsl:apply-templates select="url"/></TD>
		<TD align="center"><xsl:value-of select="info"/></TD>
	</TR>
</xsl:template>

<xsl:template match="url">
	<xsl:if test=". != ''">
	<xsl:element name="A">
		<xsl:attribute name="href">
			<xsl:value-of select="."/>
		</xsl:attribute>[link]</xsl:element>
	</xsl:if>
</xsl:template>

</xsl:stylesheet>
<!-- EOF -->
